==> haskell-string-conversions-0.4.0.1-182-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 string-conversions
version:              0.4.0.1
visibility:           public
id:                   string-conversions-0.4.0.1-GMxiYjpb0DV8x5MWrJix2r
key:                  string-conversions-0.4.0.1-GMxiYjpb0DV8x5MWrJix2r
license:              BSD-3-Clause
maintainer:           soenkehahn@gmail.com
author:               Sönke Hahn
homepage:             https://github.com/soenkehahn/string-conversions#readme
synopsis:             Simplifies dealing with different types for strings
description:
    Provides a simple type class for converting values of different string types into values of other string types.

category:             Data
abi:                  d5038866f9d058e74c939aef3c3f9a44
exposed:              True
exposed-modules:
    Data.String.Conversions Data.String.Conversions.Monomorphic

import-dirs:          /usr/lib/ghc-9.2.8/site-local/string-conversions-0.4.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/string-conversions-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-conversions
hs-libraries:         HSstring-conversions-0.4.0.1-GMxiYjpb0DV8x5MWrJix2r
depends:
    base-4.16.4.0 bytestring-0.11.4.0 text-1.2.5.0
    utf8-string-1.0.2-AaPuiI83MyhDGzjGdO2RZO

haddock-interfaces:
    /usr/share/doc/haskell-string-conversions/html/string-conversions.haddock

haddock-html:         /usr/share/doc/haskell-string-conversions/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-string-conversions-0.4.0.1-183-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 string-conversions
version:              0.4.0.1
visibility:           public
id:                   string-conversions-0.4.0.1-D6xKa1tiiemJrtOXoXDyxy
key:                  string-conversions-0.4.0.1-D6xKa1tiiemJrtOXoXDyxy
license:              BSD-3-Clause
maintainer:           soenkehahn@gmail.com
author:               Sönke Hahn
homepage:             https://github.com/soenkehahn/string-conversions#readme
synopsis:             Simplifies dealing with different types for strings
description:
    Provides a simple type class for converting values of different string types into values of other string types.

category:             Data
abi:                  b5cdcf38219b3f3a951260d297cf0f8b
exposed:              True
exposed-modules:
    Data.String.Conversions Data.String.Conversions.Monomorphic

import-dirs:          /usr/lib/ghc-9.2.8/site-local/string-conversions-0.4.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/string-conversions-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-conversions
hs-libraries:         HSstring-conversions-0.4.0.1-D6xKa1tiiemJrtOXoXDyxy
depends:
    base-4.16.4.0 bytestring-0.11.4.0 text-1.2.5.0
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI

haddock-interfaces:
    /usr/share/doc/haskell-string-conversions/html/string-conversions.haddock

haddock-html:         /usr/share/doc/haskell-string-conversions/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
